Action enum

Which indexing operation to perform: - addObject: adds records to an index. Equivalent to the "Add a new record (with auto-generated object ID)" operation. - updateObject: adds or replaces records in an index. Equivalent to the "Add or replace a record" operation. - partialUpdateObject: adds or updates attributes within records. Equivalent to the "Add or update attributes" operation with the createIfNoExists parameter set to true. (If a record with the specified objectID doesn't exist in the specified index, this action creates adds the record to the index) - partialUpdateObjectNoCreate: same as partialUpdateObject, but with createIfNoExists set to false. (A record isn't added to the index if its objectID doesn't exist) - deleteObject: delete records from an index. Equivalent to the "Delete a record" operation. - delete. Delete an index. Equivalent to the "Delete an index" operation. - clear: delete all records from an index. Equivalent to the "Delete all records from an index operation".

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(valueField: 'raw')

Values

addObject → const Action
const Action(r'addObject')
updateObject → const Action
const Action(r'updateObject')
partialUpdateObject → const Action
const Action(r'partialUpdateObject')
partialUpdateObjectNoCreate → const Action
const Action(r'partialUpdateObjectNoCreate')
deleteObject → const Action
const Action(r'deleteObject')
delete → const Action
const Action(r'delete')
clear → const Action
const Action(r'clear')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
raw → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) Action

Constants

values → const List<Action>
A constant List of the values in this enum, in order of their declaration.