Determines whether promoted records must also match active filters for the consequence to apply. This ensures user-applied filters take priority and irrelevant matches aren't shown. For example, if you promote a record with color: red but the user filters for color: blue, the "red" record won't be shown. > In the Algolia dashboard, when you use the Pin an item consequence, filterPromotes appears as the checkbox: Pinned items must match active filters to be displayed. For examples, see Promote results with rules.
Records you want to pin to a specific position in the search results. You can promote up to 300 records, either individually, or as groups of up to 100 records each.
One of types:
A JSON object with custom data that will be appended to the userData array in the response. This object isn't interpreted by the API and is limited to 1 kB of minified JSON.