timestamp property
Timestamp of the event, measured in milliseconds since the Unix epoch. Must be no older than 30 days. If not provided, we use the time at which the request was received.
Implementation
@JsonKey(name: r'timestamp')
final int? timestamp;