SearchExtensionsQueryCategorization class final

Annotations
  • @JsonSerializable.new()

Constructors

SearchExtensionsQueryCategorization({bool? enableCategoriesRetrieval, bool? enableAutoFiltering})
Returns a new SearchExtensionsQueryCategorization instance.
const
SearchExtensionsQueryCategorization.fromJson(Map<String, dynamic> json)
factory

Properties

enableAutoFiltering bool?
Whether to automatically apply category-based filters and boosts to search results.
final
enableCategoriesRetrieval bool?
Whether to retrieve category predictions in the response extensions.queryCategorization field.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override