enableCategoriesRetrieval property
Whether to retrieve category predictions in the response extensions.queryCategorization field.
Implementation
@JsonKey(name: r'enableCategoriesRetrieval')
final bool? enableCategoriesRetrieval;
Whether to retrieve category predictions in the response extensions.queryCategorization field.
@JsonKey(name: r'enableCategoriesRetrieval')
final bool? enableCategoriesRetrieval;