userToken property

  1. @JsonKey.new(name: r'userToken')
String? userToken
final

Pseudonymous user identifier to restrict usage of this API key to specific users. By default, rate limits are set based on IP addresses. This can be an issue if many users search from the same IP address. To avoid this, add a user token to each generated API key.

Implementation

@JsonKey(name: r'userToken')
final String? userToken;