AutoFilteringResult class final

Annotations
  • @JsonSerializable.new()

Constructors

AutoFilteringResult({bool? enabled, int? maxDepth, Iterable? facetFilters, Iterable? optionalFilters})
Returns a new AutoFilteringResult instance.
const
AutoFilteringResult.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
Whether automatic filtering was applied to this query.
final
facetFilters → Iterable?
Facet filters automatically applied to the query. One of types:
final
hashCode → int
The hash code for this object.
no setteroverride
maxDepth → int?
Maximum category hierarchy depth used for filtering.
final
optionalFilters → Iterable?
Optional filters automatically applied to boost relevant categories. One of types:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override