BaseSearchResponse class final

Implemented types
Annotations
  • @JsonSerializable.new(createFieldMap: true)

Constructors

BaseSearchResponse({int? abTestID, int? abTestVariantID, String? aroundLatLng, String? automaticRadius, Exhaustive? exhaustive, List<Object>? appliedRules, bool? exhaustiveFacetsCount, bool? exhaustiveNbHits, bool? exhaustiveTypo, Map<String, Map<String, int>>? facets, Map<String, FacetStats>? facetsStats, String? index, String? indexUsed, String? message, int? nbSortedHits, String? parsedQuery, int? processingTimeMS, Object? processingTimingsMS, String? queryAfterRemoval, Redirect? redirect, RenderingContent? renderingContent, int? serverTimeMS, String? serverUsed, Object? userData, String? queryID, bool? automaticInsights, Map<String, dynamic> additionalProperties = const {}})
Returns a new BaseSearchResponse instance.
const
BaseSearchResponse.fromJson(Map<String, dynamic> json)
factory

Properties

abTestID → int?
A/B test ID. This is only included in the response for indices that are part of an A/B test.
final
abTestVariantID → int?
Variant ID. This is only included in the response for indices that are part of an A/B test.
final
appliedRules → List<Object>?
Rules applied to the query.
final
aroundLatLng → String?
Computed geographical location.
final
automaticInsights → bool?
Whether automatic events collection is enabled for the application.
final
automaticRadius → String?
Distance from a central coordinate provided by aroundLatLng.
final
entries → Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setterinherited
exhaustive → Exhaustive?
final
exhaustiveFacetsCount → bool?
See the facetsCount field of the exhaustive object in the response.
final
exhaustiveNbHits → bool?
See the nbHits field of the exhaustive object in the response.
final
exhaustiveTypo → bool?
See the typo field of the exhaustive object in the response.
final
facets → Map<String, Map<String, int>>?
Facet counts.
final
facetsStats → Map<String, FacetStats>?
Statistics for numerical facets.
final
hashCode → int
The hash code for this object.
no setteroverride
index → String?
Index name used for the query.
final
indexUsed → String?
Index name used for the query. During A/B testing, the targeted index isn't always the index used by the query.
final
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<String>
The keys of this Map.
no setterinherited
length → int
The number of key/value pairs in the map.
no setterinherited
message → String?
Warnings about the query.
final
nbSortedHits → int?
Number of hits selected and sorted by the relevant sort algorithm.
final
parsedQuery → String?
Post-normalization query string that will be searched.
final
processingTimeMS → int?
Time the server took to process the request, in milliseconds.
final
processingTimingsMS → Object?
Experimental. List of processing steps and their times, in milliseconds. You can use this list to investigate performance issues.
final
queryAfterRemoval → String?
Markup text indicating which parts of the original query have been removed to retrieve a non-empty result set.
final
queryID → String?
Unique identifier for the query. This is used for click analytics.
final
redirect → Redirect?
final
renderingContent → RenderingContent?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverTimeMS → int?
Time the server took to process the request, in milliseconds.
final
serverUsed → String?
Host name of the server that processed the request.
final
userData → Object?
An object with custom data. You can store up to 32kB as custom data.
final
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<String, dynamic>> entries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<K2, V2>() → Map<K2, V2>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void f(String, dynamic)) → void
Applies action to each key/value pair of the map.
inherited
map<K2, V2>(MapEntry<K2, V2> transform(String, dynamic)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
inherited
removeWhere(bool test(String, dynamic)) → void
Removes all entries of this map that satisfy the given test.
inherited
retype<K2, V2>() → Map<K2, V2>
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
update(String key, dynamic update(dynamic), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(String, dynamic)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
inherited
operator []=(String key, dynamic value) → void
Associates the key with the given value.
inherited