BrowseResponse class final

Annotations
  • @JsonSerializable.new()

Constructors

BrowseResponse({int? abTestID, int? abTestVariantID, String? aroundLatLng, String? automaticRadius, Exhaustive? exhaustive, List<Object>? appliedRules, bool? exhaustiveFacetsCount, bool? exhaustiveNbHits, bool? exhaustiveTypo, Map<String, Map<String, int>>? facets, Map<String, FacetStats>? facetsStats, String? index, String? indexUsed, String? message, int? nbSortedHits, String? parsedQuery, int? processingTimeMS, Object? processingTimingsMS, String? queryAfterRemoval, Redirect? redirect, RenderingContent? renderingContent, int? serverTimeMS, String? serverUsed, Object? userData, String? queryID, bool? automaticInsights, int? page, int? nbHits, int? nbPages, int? hitsPerPage, required List<Hit> hits, String? query, String? params, ResponseExtensions? extensions, String? cursor})
Returns a new BrowseResponse instance.
const
BrowseResponse.fromJson(Map<String, dynamic> json)
factory

Properties

abTestID → int?
A/B test ID. This is only included in the response for indices that are part of an A/B test.
final
abTestVariantID → int?
Variant ID. This is only included in the response for indices that are part of an A/B test.
final
appliedRules → List<Object>?
Rules applied to the query.
final
aroundLatLng → String?
Computed geographical location.
final
automaticInsights → bool?
Whether automatic events collection is enabled for the application.
final
automaticRadius → String?
Distance from a central coordinate provided by aroundLatLng.
final
cursor → String?
Cursor to get the next page of the response. The parameter must match the value returned in the response of a previous request. The last page of the response does not return a cursor attribute.
final
exhaustive → Exhaustive?
final
exhaustiveFacetsCount → bool?
See the facetsCount field of the exhaustive object in the response.
final
exhaustiveNbHits → bool?
See the nbHits field of the exhaustive object in the response.
final
exhaustiveTypo → bool?
See the typo field of the exhaustive object in the response.
final
extensions → ResponseExtensions?
final
facets → Map<String, Map<String, int>>?
Facet counts.
final
facetsStats → Map<String, FacetStats>?
Statistics for numerical facets.
final
hashCode → int
The hash code for this object.
no setteroverride
hits → List<Hit>
Search results (hits). Hits are records from your index that match the search criteria, augmented with additional attributes, such as, for highlighting.
final
hitsPerPage → int?
Number of hits per page.
final
index → String?
Index name used for the query.
final
indexUsed → String?
Index name used for the query. During A/B testing, the targeted index isn't always the index used by the query.
final
message → String?
Warnings about the query.
final
nbHits → int?
Number of results (hits).
final
nbPages → int?
Number of pages of results.
final
nbSortedHits → int?
Number of hits selected and sorted by the relevant sort algorithm.
final
page → int?
Page of search results to retrieve.
final
params → String?
URL-encoded string of all search parameters.
final
parsedQuery → String?
Post-normalization query string that will be searched.
final
processingTimeMS → int?
Time the server took to process the request, in milliseconds.
final
processingTimingsMS → Object?
Experimental. List of processing steps and their times, in milliseconds. You can use this list to investigate performance issues.
final
query → String?
Search query.
final
queryAfterRemoval → String?
Markup text indicating which parts of the original query have been removed to retrieve a non-empty result set.
final
queryID → String?
Unique identifier for the query. This is used for click analytics.
final
redirect → Redirect?
final
renderingContent → RenderingContent?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverTimeMS → int?
Time the server took to process the request, in milliseconds.
final
serverUsed → String?
Host name of the server that processed the request.
final
userData → Object?
An object with custom data. You can store up to 32kB as custom data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override