CategoryPrediction class final

Annotations
  • @JsonSerializable.new()

Constructors

CategoryPrediction({CategoryPredictionBin? bin, List<HierarchyPathEntry>? hierarchyPath})
Returns a new CategoryPrediction instance.
const
CategoryPrediction.fromJson(Map<String, dynamic> json)
factory

Properties

bin CategoryPredictionBin?
final
hashCode int
The hash code for this object.
no setteroverride
hierarchyPath List<HierarchyPathEntry>?
Ordered list of category levels from root to the predicted category.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override