Cursor class final

Annotations
  • @JsonSerializable.new()

Constructors

Cursor({String? cursor})
Returns a new Cursor instance.
const
Cursor.fromJson(Map<String, dynamic> json)
factory

Properties

cursor → String?
Cursor to get the next page of the response. The parameter must match the value returned in the response of a previous request. The last page of the response does not return a cursor attribute.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override