Edit class final

Annotations
  • @JsonSerializable.new()

Constructors

Edit({EditType? type, String? delete, String? insert})
Returns a new Edit instance.
const
Edit.fromJson(Map<String, dynamic> json)
factory

Properties

delete → String?
Text or patterns to remove from the query string.
final
hashCode → int
The hash code for this object.
no setteroverride
insert → String?
Text to be added in place of the deleted text inside the query string.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → EditType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override