FacetHits class final

Annotations
  • @JsonSerializable.new()

Constructors

FacetHits({required String value, required String highlighted, required int count})
Returns a new FacetHits instance.
const
FacetHits.fromJson(Map<String, dynamic> json)
factory

Properties

count → int
Number of records with this facet value. The count may be approximated.
final
hashCode → int
The hash code for this object.
no setteroverride
highlighted → String
Highlighted attribute value, including HTML tags.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Facet value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override