FacetStats class final

Annotations
  • @JsonSerializable.new()

Constructors

FacetStats({double? min, double? max, double? avg, double? sum})
Returns a new FacetStats instance.
const
FacetStats.fromJson(Map<String, dynamic> json)
factory

Properties

avg → double?
Average facet value in the results.
final
hashCode → int
The hash code for this object.
no setteroverride
max → double?
Maximum value in the results.
final
min → double?
Minimum value in the results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sum → double?
Sum of all values in the results.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override