HierarchyPathEntry class final

Annotations
  • @JsonSerializable.new()

Constructors

HierarchyPathEntry({String? facetName, String? facetValue, int? depth})
Returns a new HierarchyPathEntry instance.
const
HierarchyPathEntry.fromJson(Map<String, dynamic> json)
factory

Properties

depth → int?
Depth level in the category hierarchy, starting at 0.
final
facetName → String?
Facet attribute name at this hierarchy level, for example, categories.lvl0.
final
facetValue → String?
Facet value at this level of the category hierarchy.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override