facetValue property
Facet value at this level of the category hierarchy.
Implementation
@JsonKey(name: r'facetValue')
final String? facetValue;
Facet value at this level of the category hierarchy.
@JsonKey(name: r'facetValue')
final String? facetValue;