MatchedGeoLocation class final

Annotations
  • @JsonSerializable.new()

Constructors

MatchedGeoLocation({double? lat, double? lng, int? distance})
Returns a new MatchedGeoLocation instance.
const
MatchedGeoLocation.fromJson(Map<String, dynamic> json)
factory

Properties

distance → int?
Distance between the matched location and the search location (in meters).
final
hashCode → int
The hash code for this object.
no setteroverride
lat → double?
Latitude of the matched location.
final
lng → double?
Longitude of the matched location.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override