QueryCategorization class final

Annotations
  • @JsonSerializable.new()

Constructors

QueryCategorization({String? normalizedQuery, int? count, QueryCategorizationType? type, List<CategoryPrediction>? categories, AutoFilteringResult? autofiltering})
Returns a new QueryCategorization instance.
const
QueryCategorization.fromJson(Map<String, dynamic> json)
factory

Properties

autofiltering → AutoFilteringResult?
final
categories → List<CategoryPrediction>?
List of category predictions with confidence levels.
final
count → int?
Number of times this normalized query was observed during the training window.
final
hashCode → int
The hash code for this object.
no setteroverride
normalizedQuery → String?
Processed and normalized version of the original search query.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → QueryCategorizationType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override