count property
Number of times this normalized query was observed during the training window.
Implementation
@JsonKey(name: r'count')
final int? count;
Number of times this normalized query was observed during the training window.
@JsonKey(name: r'count')
final int? count;