RankingInfo class final

Annotations
  • @JsonSerializable.new()

Constructors

RankingInfo({int? filters, required int firstMatchedWord, required int geoDistance, int? geoPrecision, MatchedGeoLocation? matchedGeoLocation, Personalization? personalization, required int nbExactWords, required int nbTypos, bool? promoted, int? proximityDistance, required int userScore, int? words, bool? promotedByReRanking})
Returns a new RankingInfo instance.
const
RankingInfo.fromJson(Map<String, dynamic> json)
factory

Properties

filters → int?
Whether a filter matched the query.
final
firstMatchedWord → int
Position of the first matched word in the best matching attribute of the record.
final
geoDistance → int
Distance between the geo location in the search query and the best matching geo location in the record, divided by the geo precision (in meters).
final
geoPrecision → int?
Precision used when computing the geo distance, in meters.
final
hashCode → int
The hash code for this object.
no setteroverride
matchedGeoLocation → MatchedGeoLocation?
final
nbExactWords → int
Number of exactly matched words.
final
nbTypos → int
Number of typos encountered when matching the record.
final
personalization → Personalization?
final
Whether the record was promoted by a rule.
final
promotedByReRanking → bool?
Whether the record is re-ranked.
final
proximityDistance → int?
Number of words between multiple matches in the query plus 1. For single word queries, proximityDistance is 0.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userScore → int
Overall ranking of the record, expressed as a single integer. This attribute is internal.
final
words → int?
Number of matched words.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override