RedirectRuleIndexMetadata class final

Annotations
  • @JsonSerializable.new()

Constructors

RedirectRuleIndexMetadata({required String source, required String dest, required String reason, required bool succeed, required RedirectRuleIndexData data})
Returns a new RedirectRuleIndexMetadata instance.
const
RedirectRuleIndexMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

data → RedirectRuleIndexData
final
dest → String
Destination index for the redirect rule.
final
hashCode → int
The hash code for this object.
no setteroverride
reason → String
Reason for the redirect rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
Source index for the redirect rule.
final
succeed → bool
Redirect rule status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override