RenderingContent class final

Annotations
  • @JsonSerializable.new()

Constructors

RenderingContent({FacetOrdering? facetOrdering, RedirectURL? redirect, Widgets? widgets})
Returns a new RenderingContent instance.
const
RenderingContent.fromJson(Map<String, dynamic> json)
factory

Properties

facetOrdering → FacetOrdering?
final
hashCode → int
The hash code for this object.
no setteroverride
redirect → RedirectURL?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgets → Widgets?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override