SearchForFacetValuesResponse class final

Annotations
  • @JsonSerializable.new()

Constructors

SearchForFacetValuesResponse({required List<FacetHits> facetHits, required bool exhaustiveFacetsCount, int? processingTimeMS})
Returns a new SearchForFacetValuesResponse instance.
const
SearchForFacetValuesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

exhaustiveFacetsCount → bool
Whether the facet count is exhaustive (true) or approximate (false). For more information, see Why are my facet and hit counts not accurate.
final
facetHits → List<FacetHits>
Matching facet values.
final
hashCode → int
The hash code for this object.
no setteroverride
processingTimeMS → int?
Time the server took to process the request, in milliseconds.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override