SearchForFacetsOptions class final

Annotations
  • @JsonSerializable.new()

Constructors

SearchForFacetsOptions({required String facet, required String indexName, String? facetQuery, int? maxFacetHits, required SearchTypeFacet type})
Returns a new SearchForFacetsOptions instance.
const
SearchForFacetsOptions.fromJson(Map<String, dynamic> json)
factory

Properties

facet → String
Facet name.
final
facetQuery → String?
Text to search inside the facet's values.
final
hashCode → int
The hash code for this object.
no setteroverride
indexName → String
Index name (case-sensitive).
final
maxFacetHits → int?
Maximum number of facet values to return when searching for facet values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SearchTypeFacet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override