SearchHits class final

Implemented types
Annotations
  • @JsonSerializable.new(createFieldMap: true)

Constructors

SearchHits({required List<Hit> hits, String? query, String? params, ResponseExtensions? extensions, Map<String, dynamic> additionalProperties = const {}})
Returns a new SearchHits instance.
const
SearchHits.fromJson(Map<String, dynamic> json)
factory

Properties

entries → Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setterinherited
extensions → ResponseExtensions?
final
hashCode → int
The hash code for this object.
no setteroverride
hits → List<Hit>
Search results (hits). Hits are records from your index that match the search criteria, augmented with additional attributes, such as, for highlighting.
final
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<String>
The keys of this Map.
no setterinherited
length → int
The number of key/value pairs in the map.
no setterinherited
params → String?
URL-encoded string of all search parameters.
final
query → String?
Search query.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<String, dynamic>> entries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<K2, V2>() → Map<K2, V2>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void f(String, dynamic)) → void
Applies action to each key/value pair of the map.
inherited
map<K2, V2>(MapEntry<K2, V2> transform(String, dynamic)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
inherited
removeWhere(bool test(String, dynamic)) → void
Removes all entries of this map that satisfy the given test.
inherited
retype<K2, V2>() → Map<K2, V2>
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
update(String key, dynamic update(dynamic), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(String, dynamic)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
inherited
operator []=(String key, dynamic value) → void
Associates the key with the given value.
inherited