SearchPagination class final

Annotations
  • @JsonSerializable.new()

Constructors

SearchPagination({int? page, int? nbHits, int? nbPages, int? hitsPerPage})
Returns a new SearchPagination instance.
const
SearchPagination.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
hitsPerPage → int?
Number of hits per page.
final
nbHits → int?
Number of results (hits).
final
nbPages → int?
Number of pages of results.
final
page → int?
Page of search results to retrieve.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override