SearchParamsString class final

Annotations
  • @JsonSerializable.new()

Constructors

SearchParamsString({String? params})
Returns a new SearchParamsString instance.
const
SearchParamsString.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
params → String?
Search parameters as a URL-encoded query string.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override