input property
Word or phrase to appear in query strings (for onewaysynonyms).
Implementation
@JsonKey(name: r'input')
final String? input;
Word or phrase to appear in query strings (for onewaysynonyms).
@JsonKey(name: r'input')
final String? input;