TrendingFacetHit class final

Annotations
  • @JsonSerializable.new()

Constructors

TrendingFacetHit({double? score, required String facetName, required String facetValue})
Returns a new TrendingFacetHit instance.
const
TrendingFacetHit.fromJson(Map<String, dynamic> json)
factory

Properties

facetName → String
Facet attribute. To be used in combination with facetValue. If specified, only recommendations matching the facet filter will be returned.
final
facetValue → String
Facet value. To be used in combination with facetName. If specified, only recommendations matching the facet filter will be returned.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
Recommendation score.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override