Value class final

Annotations
  • @JsonSerializable.new()

Constructors

Value({List<String>? order, SortRemainingBy? sortRemainingBy, List<String>? hide})
Returns a new Value instance.
const
Value.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
hide → List<String>?
Hide facet values.
final
order → List<String>?
Explicit order of facets or facet values. This setting lets you always show specific facets or facet values at the top of the list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortRemainingBy → SortRemainingBy?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override